{% extends 'generic/object.html' %}
{% load helpers %}
{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Document Type</h5>
        <div class="card-body">
          <table class="table table-hover attr-table">
            <tr>
              <th scope="row">Name</th>
              <td>{{ object.name|placeholder }}</td>
            </tr>
            <tr>
              <th scope="row">Color</th>
              <td>
                  <span class="color-label" style="background-color: #{{ object.color }}">&nbsp;</span>
              </td>
            </tr>
              <tr>
              <th scope="row">Document count</th>
              <td>
                  <a href="{% url 'plugins:netbox_ged:document_list' %}?document_type_id={{ object.pk }}">{{ object.documents.count }}</a>
              </td>
            </tr>
          </table>
        </div>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
    </div>
  </div>
{% endblock content %}